library(reshape2)
library(plyr)
library(tidyverse)
library(readxl)
library(plm)
library(stargazer)


# ========================= # ========================= # =========================
# Section 1. Input data from: FAO, PSD, ICRG, WBO and WDR

# =========================
# 1.1: FAO
# Inland water
Inland.water <- read.csv("D:/food security/2021_revise/data2020/FAOSTAT_inland_water.csv")
Inland.water <- Inland.water[,c("Area","Year","Value")]
names(Inland.water) <- c("Country","Year","Inland.water")

# Producer Price Index
PPI <- read.csv("D:/food security/2021_revise/data2020/FAOSTAT_price.csv")
PPI <- subset(PPI[, c("Area", "Year", "Item", "Value")],
              PPI$Item == "Rice, paddy" |
                PPI$Item == "Wheat" |
                PPI$Item == "Barley" |
                PPI$Item == "Oats" |
                PPI$Item == "Sorghum")
                # PPI$Item == "Grain, mixed" |
                # PPI$Item == "Millet" |
                # PPI$Item == "Rye" |
                # PPI$Item == "popcorn")
PPI <- dcast(PPI, Area ~ Year, value.var = "Value", fun.aggregate = sum, na.rm = TRUE)
PPI <- melt(PPI, id.vars = "Area", measure.vars = colnames(PPI)[-1],
            variable.name = "Year", value.name = "PPI")
names(PPI) <- c("Country", "Year", "PPI")

# setdiff(unique(Inland.water$Country), unique(PPI$Country))
# setdiff(unique(PPI$Country), unique(Inland.water$Country))
ALL <- merge(Inland.water, PPI, by = c("Country", "Year"))

# =========================
# 1.2: PSD
PSD <- read.csv("D:/food security/2021_revise/data2020/psd_alldata.csv")

# 1.2.1
Area.Harvested <- data.frame(subset(PSD, 
                                    (Commodity_Description == "Wheat" |
                                       Commodity_Description == "Rice, Milled" |
                                       Commodity_Description == "Barley" |
                                       Commodity_Description == "Oats" |
                                       Commodity_Description == "Sorghum") &
                                       # Commodity_Description == "Mixed grain" |
                                       # Commodity_Description == "Millet" |
                                       # Commodity_Description == "Rye" |
                                       # Commodity_Description == "Corn") &
                                      Attribute_Description == "Area Harvested",
                                    select = c(Country_Name, Market_Year, Commodity_Description, Value)))
Area.Harvested <- dcast(Area.Harvested, Country_Name ~ Market_Year, value.var = "Value", fun.aggregate = sum)
Area.Harvested <- melt(Area.Harvested, id.vars = "Country_Name", measure.vars = colnames(Area.Harvested)[-1],
                       variable.name = "Year", value.name = "Area.Harvested") 
# 1.2.2
Beginning.Stocks <- data.frame(subset(PSD, 
                                      (Commodity_Description == "Wheat" |
                                         Commodity_Description == "Rice, Milled" |
                                         Commodity_Description == "Barley" |
                                         Commodity_Description == "Oats" |
                                         Commodity_Description == "Sorghum") &
                                         # Commodity_Description == "Mixed grain" |
                                         # Commodity_Description == "Millet" |
                                         # Commodity_Description == "Rye" |
                                         # Commodity_Description == "Corn") &
                                        Attribute_Description == "Beginning Stocks",
                                      select = c(Country_Name, Market_Year, Commodity_Description, Value)))
Beginning.Stocks <- dcast(Beginning.Stocks, Country_Name ~ Market_Year, value.var = "Value", fun.aggregate = sum)
Beginning.Stocks <- melt(Beginning.Stocks, id.vars = "Country_Name", measure.vars = colnames(Beginning.Stocks)[-1],
                         variable.name = "Year", value.name = "Beginning.Stocks") 
# 1.2.3
Domestic.Consumption <- data.frame(subset(PSD, 
                                          (Commodity_Description == "Wheat" |
                                             Commodity_Description == "Rice, Milled" |
                                             Commodity_Description == "Barley" |
                                             Commodity_Description == "Oats" |
                                             Commodity_Description == "Sorghum") &
                                             # Commodity_Description == "Mixed grain" |
                                             # Commodity_Description == "Millet" |
                                             # Commodity_Description == "Rye" |
                                             # Commodity_Description == "Corn") &
                                            Attribute_Description == "Domestic Consumption",
                                          select = c(Country_Name, Market_Year, Commodity_Description, Value)))
Domestic.Consumption <- dcast(Domestic.Consumption, Country_Name ~ Market_Year, value.var = "Value", fun.aggregate = sum)
Domestic.Consumption <- melt(Domestic.Consumption, id.vars = "Country_Name", measure.vars = colnames(Domestic.Consumption)[-1],
                             variable.name = "Year", value.name = "Domestic.Consumption") 
# 1.2.4
Ending.Stocks <- data.frame(subset(PSD, 
                                   (Commodity_Description == "Wheat" |
                                      Commodity_Description == "Rice, Milled" |
                                      Commodity_Description == "Barley" |
                                      Commodity_Description == "Oats" |
                                      Commodity_Description == "Sorghum") &
                                      # Commodity_Description == "Mixed grain" |
                                      # Commodity_Description == "Millet" |
                                      # Commodity_Description == "Rye" |
                                      # Commodity_Description == "Corn") &
                                     Attribute_Description == "Ending Stocks",
                                   select = c(Country_Name, Market_Year, Commodity_Description, Value)))
Ending.Stocks <- dcast(Ending.Stocks, Country_Name ~ Market_Year, value.var = "Value", fun.aggregate = sum)
Ending.Stocks <- melt(Ending.Stocks, id.vars = "Country_Name", measure.vars = colnames(Ending.Stocks)[-1],
                      variable.name = "Year", value.name = "Ending.Stocks") 
# 1.2.5
Exports <- data.frame(subset(PSD, 
                             (Commodity_Description == "Wheat" |
                                Commodity_Description == "Rice, Milled" |
                                Commodity_Description == "Barley" |
                                Commodity_Description == "Oats" |
                                Commodity_Description == "Sorghum") &
                                # Commodity_Description == "Mixed grain" |
                                # Commodity_Description == "Millet" |
                                # Commodity_Description == "Rye" |
                                # Commodity_Description == "Corn") &
                               Attribute_Description == "Exports",
                             select = c(Country_Name, Market_Year, Commodity_Description, Value)))
Exports <- dcast(Exports, Country_Name ~ Market_Year, value.var = "Value", fun.aggregate = sum)
Exports <- melt(Exports, id.vars = "Country_Name", measure.vars = colnames(Exports)[-1],
                variable.name = "Year", value.name = "Exports") 
# 1.2.6
FSI.Consumption <- data.frame(subset(PSD, 
                                     (Commodity_Description == "Wheat" |
                                        Commodity_Description == "Rice, Milled" |
                                        Commodity_Description == "Barley" |
                                        Commodity_Description == "Oats" |
                                        Commodity_Description == "Sorghum") &
                                        # Commodity_Description == "Mixed grain" |
                                        # Commodity_Description == "Millet" |
                                        # Commodity_Description == "Rye" |
                                        # Commodity_Description == "Corn") &
                                       Attribute_Description == "FSI Consumption",
                                     select = c(Country_Name, Market_Year, Value, Commodity_Description)))
FSI.Consumption <- dcast(FSI.Consumption, Country_Name ~ Market_Year, value.var = "Value", fun.aggregate = sum)
FSI.Consumption <- melt(FSI.Consumption, id.vars = "Country_Name", measure.vars = colnames(FSI.Consumption)[-1],
                        variable.name = "Year", value.name = "FSI.Consumption") 
# 1.2.7
Imports <- data.frame(subset(PSD, 
                             (Commodity_Description == "Wheat" |
                                Commodity_Description == "Rice, Milled" |
                                Commodity_Description == "Barley" |
                                Commodity_Description == "Oats" |
                                Commodity_Description == "Sorghum") &
                                # Commodity_Description == "Mixed grain" |
                                # Commodity_Description == "Millet" |
                                # Commodity_Description == "Rye" |
                                # Commodity_Description == "Corn") &
                               Attribute_Description == "Imports",
                             select = c(Country_Name, Market_Year, Value, Commodity_Description)))
Imports <- dcast(Imports, Country_Name ~ Market_Year, value.var = "Value", fun.aggregate = sum)
Imports <- melt(Imports, id.vars = "Country_Name", measure.vars = colnames(Imports)[-1],
                variable.name = "Year", value.name = "Imports") 
# 1.2.8
Production <- data.frame(subset(PSD, 
                                (Commodity_Description == "Wheat" |
                                   Commodity_Description == "Rice, Milled" |
                                   Commodity_Description == "Barley" |
                                   Commodity_Description == "Oats" |
                                   Commodity_Description == "Sorghum") &
                                   # Commodity_Description == "Mixed grain" |
                                   # Commodity_Description == "Millet" |
                                   # Commodity_Description == "Rye" |
                                   # Commodity_Description == "Corn") &
                                  Attribute_Description == "Production",
                                select = c(Country_Name, Market_Year, Value, Commodity_Description)))
Production <- dcast(Production, Country_Name ~ Market_Year, value.var = "Value", fun.aggregate = sum)
Production <- melt(Production, id.vars = "Country_Name", measure.vars = colnames(Production)[-1],
                   variable.name = "Year", value.name = "Production") 
# 1.2.9
Yield <- data.frame(subset(PSD, 
                           (Commodity_Description == "Wheat" |
                              Commodity_Description == "Rice, Milled" |
                              Commodity_Description == "Barley" |
                              Commodity_Description == "Oats" |
                              Commodity_Description == "Sorghum") &
                              # Commodity_Description == "Mixed grain" |
                              # Commodity_Description == "Millet" |
                              # Commodity_Description == "Rye" |
                              # Commodity_Description == "Corn") &
                             Attribute_Description == "Yield",
                           select = c(Country_Name, Market_Year, Value, Commodity_Description)))
Yield <- dcast(Yield, Country_Name ~ Market_Year, value.var = "Value", fun.aggregate = sum)
Yield <- melt(Yield, id.vars = "Country_Name", measure.vars = colnames(Yield)[-1],
              variable.name = "Year", value.name = "Yield") 

PSD <- list(Area.Harvested, Beginning.Stocks, Domestic.Consumption, Ending.Stocks, 
            Exports, FSI.Consumption, Imports, Production, Yield) %>% reduce(full_join, by = c("Country_Name", "Year"))
PSD$Total.Consumption <- PSD$Domestic.Consumption + PSD$FSI.Consumption
PSD$SSR <- PSD$Production * 100 / (PSD$Production + PSD$Imports - PSD$Exports + PSD$Ending.Stocks - PSD$Beginning.Stocks)
PSD$IDR <- PSD$Imports / (PSD$Domestic.Consumption + PSD$FSI.Consumption)
PSD$Reserve.Ratio <- PSD$Beginning.Stocks * 100 / PSD$Domestic.Consumption
colnames(PSD)[1] <- "Country"

# setdiff(unique(ALL$Country), unique(PSD$Country))
# setdiff(unique(PSD$Country), unique(ALL$Country))
ALL$Country[ALL$Country == "Bolivia (Plurinational State of)"] <- "Bolivia"
ALL$Country[ALL$Country == "Brunei Darussalam"] <- "Brunei"
ALL$Country[ALL$Country == "Iran (Islamic Republic of)"] <- "Iran"
ALL$Country[ALL$Country == "Lao People's Democratic Republic"] <- "Laos"
ALL$Country[ALL$Country == "Republic of Moldova"] <- "Moldova"
ALL$Country[ALL$Country == "Russian Federation"] <- "Russia"
ALL$Country[ALL$Country == "United Kingdom of Great Britain and Northern Ireland"] <- "United Kingdom"
ALL$Country[ALL$Country == "United Republic of Tanzania"] <- "Tanzania"
ALL$Country[ALL$Country == "United States of America"] <- "United States"
ALL$Country[ALL$Country == "Venezuela (Bolivarian Republic of)"] <- "Venezuela"
ALL$Country[ALL$Country == "Viet Nam"] <- "Vietnam"
ALL$Country[ALL$Country == "Syrian Arab Republic"] <- "Syria"
ALL$Country[ALL$Country == "Czechia"] <- "Czech Republic"

PSD$Country[PSD$Country == "Congo (Brazzaville)"] <- "Congo"
PSD$Country[PSD$Country == "Gambia, The"] <- "Gambia"
PSD$Country[PSD$Country == "Korea, South"] <- "Republic of Korea"

ALL <- merge(ALL, PSD, by = c("Country", "Year"))


# =========================
# 1.3:ICRG
# ICRG new data
ICRGnew <- read.csv("D:/food security/2021_revise/data2020/ICRG2020.csv")
ICRGnew$Country <- as.character(ICRGnew$Country)
ICRGnew <- ICRGnew[,c("Country", "year",
                      "Government.Stability..A.", 
                      "Socioeconomic.Conditions..B.",
                      "Investment.Profile..C.",
                      "Internal.Conflict..D.", 
                      "External.Conflict..E.",
                      "Corruption..F.", 
                      "Military.in.Politics..G.",
                      "Religious.Tensions..H.",
                      "Law...Order..I.",
                      "Ethnic.Tensions..J.",
                      "Democratic.Accountability..K.",
                      "Bureaucracy.Quality..L.")]
ICRGnew$Political_risk <- rowSums(ICRGnew[,3:14])
ICRGnew <- ICRGnew[,c("Country", "year",
                      "Internal.Conflict..D.",
                      "External.Conflict..E.",
                      "Political_risk")]
names(ICRGnew) <- c("Country", "Year", "Internal_conflict", "External_conflict", "Political_risk")
ICRGnew <- subset(ICRGnew, Year > 2016)

# ICRG old data
Gov_stability <- read_excel("D:/food security/2021_revise/data2020/Political risk 1984_2016.xlsx", sheet = 2,col_names = TRUE, col_types = NULL, na = "", skip = 6)
Gov_stability <- melt(Gov_stability, id.vars = "Country", variable.name = "Year",
                      value.name = "Gov_stability")
Social_eco <- read_excel("D:/food security/2021_revise/data2020/Political risk 1984_2016.xlsx", sheet = 3,col_names = TRUE, col_types = NULL, na = "", skip = 6)
Social_eco <- melt(Social_eco, id.vars = "Country", variable.name = "Year",
                   value.name = "Social_eco")
Invest_profile <- read_excel("D:/food security/2021_revise/data2020/Political risk 1984_2016.xlsx", sheet = 4,col_names = TRUE, col_types = NULL, na = "", skip = 6)
Invest_profile <- melt(Invest_profile, id.vars = "Country", variable.name = "Year",
                       value.name = "Invest_profile")
Internal_conflict <- read_excel("D:/food security/2021_revise/data2020/Political risk 1984_2016.xlsx", sheet = 5,col_names = TRUE, col_types = NULL, na = "", skip = 6)
Internal_conflict <- melt(Internal_conflict, id.vars = "Country", variable.name = "Year",
                          value.name = "Internal_conflict")

External_conflict <- read_excel("D:/food security/2021_revise/data2020/Political risk 1984_2016.xlsx", sheet = 6,col_names = TRUE, col_types = NULL, na = "", skip = 6)
External_conflict <- melt(External_conflict, id.vars = "Country", variable.name = "Year",
                          value.name = "External_conflict")
Corruption <- read_excel("D:/food security/2021_revise/data2020/Political risk 1984_2016.xlsx", sheet = 7,col_names = TRUE, col_types = NULL, na = "", skip = 6)
Corruption <- melt(Corruption, id.vars = "Country", variable.name = "Year",
                   value.name = "Corruption")
Military_politics <- read_excel("D:/food security/2021_revise/data2020/Political risk 1984_2016.xlsx", sheet = 8,col_names = TRUE, col_types = NULL, na = "", skip = 6)
Military_politics <- melt(Military_politics, id.vars = "Country", variable.name = "Year",
                          value.name = "Military_politics")
Religion_politics <- read_excel("D:/food security/2021_revise/data2020/Political risk 1984_2016.xlsx", sheet = 9,col_names = TRUE, col_types = NULL, na = "", skip = 6)
Religion_politics <- melt(Religion_politics, id.vars = "Country", variable.name = "Year",
                          value.name = "Religion_politics")
Law_order <- read_excel("D:/food security/2021_revise/data2020/Political risk 1984_2016.xlsx", sheet = 10,col_names = TRUE, col_types = NULL, na = "", skip = 6)
Law_order <- melt(Law_order, id.vars = "Country", variable.name = "Year",
                  value.name = "Law_order")
Ethnic_tensions <- read_excel("D:/food security/2021_revise/data2020/Political risk 1984_2016.xlsx", sheet = 11,col_names = TRUE, col_types = NULL, na = "", skip = 6)
Ethnic_tensions <- melt(Ethnic_tensions, id.vars = "Country", variable.name = "Year",
                        value.name = "Ethnic_tensions")
Demo_account <- read_excel("D:/food security/2021_revise/data2020/Political risk 1984_2016.xlsx", sheet = 12,col_names = TRUE, col_types = NULL, na = "", skip = 6)
Demo_account <- melt(Demo_account, id.vars = "Country", variable.name = "Year",
                     value.name = "Demo_account")
Bureau_quality <- read_excel("D:/food security/2021_revise/data2020/Political risk 1984_2016.xlsx", sheet = 13,col_names = TRUE, col_types = NULL, na = "", skip = 6)
Bureau_quality <- melt(Bureau_quality, id.vars = "Country", variable.name = "Year",
                       value.name = "Bureau_quality")
ICRGold <- list(Gov_stability, Social_eco, Invest_profile, Internal_conflict,
                External_conflict, Corruption, Military_politics, Religion_politics, 
                Law_order, Ethnic_tensions,  Demo_account,  Bureau_quality) %>% 
  reduce(full_join, by = c("Country", "Year"))
ICRGold$Political_risk <- rowSums(ICRGold[,3:14])
ICRGold <- ICRGold[,c("Country", "Year", "Internal_conflict", "External_conflict", "Political_risk")]
ICRGold[,3:5] <- round(ICRGold[,3:5])


# deal with inconsistency of country name
countryold <- unique(ICRGold$Country)
countrynew <- unique(ICRGnew$Country)
# setdiff(unique(ICRGold$Country), unique(ICRGnew$Country))
# setdiff(unique(ICRGnew$Country), unique(ICRGold$Country))
ICRGnew$Country[ICRGnew$Country == "Germany, East"] <- "East Germany"
ICRGnew$Country[ICRGnew$Country == "Germany, West"] <- "West Germany"
ICRGnew$Country[ICRGnew$Country == "Korea, South"] <- "South Korea"
ICRGold$Country[ICRGold$Country == "Serbia *"] <- "Serbia"
ICRGold$Country[ICRGold$Country == "Serbia & Montenegro *"] <- "Serbia-Montenegro"


ICRGold$Year <- as.character(ICRGold$Year)
ICRGnew$Year <- as.character(ICRGnew$Year)
ICRG <- rbind(ICRGold, ICRGnew)
ICRG$Year <- as.integer(ICRG$Year)
ICRG$Political_risk <- 100 - ICRG$Political_risk
ICRG$Internal_conflict <- 12 - ICRG$Internal_conflict
ICRG$External_conflict <- 12 - ICRG$External_conflict


# setdiff(unique(ALL$Country), unique(ICRG$Country))
# setdiff(unique(ICRG$Country), unique(ALL$Country))
ICRG$Country[ICRG$Country == "South Korea"] <- "Republic of Korea"

ALL <- merge(ALL, ICRG, by = c("Country", "Year"))

# =========================
# 1.4: WBO
# Population
Population <- read.csv("D:/food security/2021_revise/data2020/WBO_Population.csv", skip = 4)
Population <- Population[,-(2:4)]
Population <- melt(Population, id.vars = "Country.Name", variable_name = "Year")
names(Population) <- c("Country", "Year", "Population")
Population$Year <- gsub("X", "", as.character(Population$Year))
Population$Year <- as.integer(Population$Year)


# GDPPC
GDPPC <- read.csv("D:/food security/2021_revise/data2020/WBO_GDPPC.csv", skip = 4)

GDPPC <- GDPPC[,-(2:4)]
GDPPC <- melt(GDPPC, id.vars = "Country.Name", variable_name = "Year")
names(GDPPC) <- c("Country", "Year", "GDPPC")
GDPPC$Year <- gsub("X", "", as.character(GDPPC$Year))
GDPPC$Year <- as.integer(GDPPC$Year)

WBO <- merge(Population, GDPPC, by = c("Country", "Year"), all = TRUE)


# setdiff(unique(ALL$Country), unique(WBO$Country))
# setdiff(unique(WBO$Country), unique(ALL$Country))
WBO$Country[WBO$Country == "Brunei Darussalam"] <- "Brunei"
WBO$Country[WBO$Country == "Congo, Rep."] <- "Congo"
WBO$Country[WBO$Country == "Egypt, Arab Rep."] <- "Egypt"
WBO$Country[WBO$Country == "Gambia, The"] <- "Gambia"
WBO$Country[WBO$Country == "Iran, Islamic Rep."] <- "Iran"
WBO$Country[WBO$Country == "Korea, Rep."] <- "Republic of Korea"
WBO$Country[WBO$Country == "Russian Federation"] <- "Russia"
WBO$Country[WBO$Country == "Slovak Republic"] <- "Slovakia"
WBO$Country[WBO$Country == "Syrian Arab Republic"] <- "Syria"
WBO$Country[WBO$Country == "Venezuela, RB"] <- "Venezuela"


ALL <- merge(ALL, WBO, by = c("Country", "Year"))
  

# =========================
# 1.5: WDR
disaster <- read.csv("D:/food security/2021_revise/data2020/emdat_public_2021_09_19_query_uid-gCALKa.csv")
disaster <- disaster[,c("Year","Country","Disaster.Type")]
disaster <- subset(disaster, Year >= 1990 & Year <= 2020)
disaster <- cbind(disaster, num = 1)
drought <- subset(disaster, Disaster.Type == "Drought")
flood <- subset(disaster, Disaster.Type == "Flood")

num.disaster_bal <- data.frame(Country = rep(unique(disaster$Country), length(1990:2020)),
                               Year = rep(unique(disaster$Year), each = length(unique(disaster$Country))))
num.disaster <- aggregate(num ~ Year + Country, disaster, sum)
num.disaster <- merge(num.disaster, num.disaster_bal, by=c("Country","Year"),all.y = TRUE)
num.disaster$num[is.na(num.disaster$num)] <- 0
num.drought <- aggregate(num ~ Year + Country, drought, sum)
num.drought <- merge(num.drought, num.disaster_bal, by=c("Country","Year"),all.y = TRUE)
num.drought$num[is.na(num.drought$num)] <- 0
num.flood <- aggregate(num ~ Year + Country, flood, sum)
num.flood <- merge(num.flood, num.disaster_bal, by=c("Country","Year"),all.y = TRUE)
num.flood$num[is.na(num.flood$num)] <- 0

disaster <- join_all(list(num.disaster, num.drought, num.flood), by = c("Country","Year"), type = "inner")
colnames(disaster) <- c("Country", "Year", "num.disaster", "num.drought", "num.flood")


# setdiff(unique(ALL$Country), unique(disaster$Country))
# setdiff(unique(disaster$Country), unique(ALL$Country))
disaster$Country[disaster$Country == "Bolivia (Plurinational State of)"] <- "Bolivia"
disaster$Country[disaster$Country == "Brunei Darussalam"] <- "Brunei"
disaster$Country[disaster$Country == "Congo (the)"] <- "Congo"
disaster$Country[disaster$Country == "Czech Republic (the)"] <- "Czech Republic"
disaster$Country[disaster$Country == "Dominican Republic (the)"] <- "Dominican Republic"
disaster$Country[disaster$Country == "Gambia (the)"] <- "Gambia"
disaster$Country[disaster$Country == "Iran (Islamic Republic of)"] <- "Iran"
disaster$Country[disaster$Country == "Moldova (the Republic of)"] <- "Moldova"
disaster$Country[disaster$Country == "Philippines (the)"] <- "Philippines"
disaster$Country[disaster$Country == "Niger (the)"] <- "Niger"
disaster$Country[disaster$Country == "Korea (the Republic of)"] <- "Republic of Korea"
disaster$Country[disaster$Country == "Russian Federation (the)"] <- "Russia"
disaster$Country[disaster$Country == "Syrian Arab Republic"] <- "Syria"
disaster$Country[disaster$Country == "Tanzania, United Republic of"] <- "Tanzania"
disaster$Country[disaster$Country ==  "United Kingdom of Great Britain and Northern Ireland (the)"] <- "United Kingdom"
disaster$Country[disaster$Country ==  "United States of America (the)"] <- "United States"
disaster$Country[disaster$Country ==  "Venezuela (Bolivarian Republic of)"] <- "Venezuela"
disaster$Country[disaster$Country ==  "Viet Nam"] <- "Vietnam"

ALL <- merge(ALL, disaster, by = c("Country", "Year")) 


# ALL <- join_all(list(PPI, Inland.water, PSD, ICRG, WBO, disaster), 
#                 by = c("Country","Year"), type = "inner")
# unique(ALL$Country)
# unique(ALL$Year)



# ========================= # ========================= # =========================
# Section 2. Add grouping variables

# ========================= 
# 2.1 machinery
# Note: 1 means high quantity of machinery
machinery <- read.csv("D:/food security/2021_revise/data2020/Investment_Machinery_E_All_Data.csv")[-1]
# unique(machinery$Item)
# Note: 8 Items include:
# Agricultural tractors, total; Balers (straw and fodder balers including pick-up balers);
# Combine harvesters - threshers; Manure spreaders and Fertiliser distributors;
# Ploughs (e.g. reversible and non-reversible ploughs); Root or tuber harvesting machines;
# Threshing machines; Seeders, planters and transplanters
machinery <- subset(machinery, machinery$ItemCode == "2455009" |
                        machinery$ItemCode == "2455005" |
                        machinery$ItemCode == "2455004" |
                        machinery$ItemCode == "2455003" |
                        machinery$ItemCode == "2455001" |
                        machinery$ItemCode == "2455006" |
                        machinery$ItemCode == "2455007" |
                        machinery$ItemCode == "2455002")
machinery <- subset(machinery, machinery$Element == "In Use")
machinery <- machinery[, c("Country", "Year", "Value")]
machinery <- subset(machinery, !is.na(machinery$Value))
# setdiff(unique(df$Country), unique(machinery$Country))
# rename machinery dataset for 9 countries:
machinery$Country <- as.character(machinery$Country)
machinery$Country[machinery$Country == "Bolivia (Plurinational State of)"] <- "Bolivia"
machinery$Country[machinery$Country == "Brunei Darussalam"] <- "Brunei"
machinery$Country[machinery$Country == "Iran (Islamic Republic of)"] <- "Iran"
machinery$Country[machinery$Country == "Republic of Moldova"] <- "Moldova"
machinery$Country[machinery$Country == "Russian Federation"] <- "Russia"
machinery$Country[machinery$Country == "Syrian Arab Republic"] <- "Syria"
machinery$Country[machinery$Country == "United States of America"] <- "United States"
machinery$Country[machinery$Country == "Venezuela (Bolivarian Republic of)"] <- "Venezuela"
machinery$Country[machinery$Country == "Viet Nam"] <- "Vietnam"

machinery <- data.frame(tapply(machinery$Value, machinery$Country, mean, na.rm = TRUE))
machinery["Country"] <- rownames(machinery)
colnames(machinery)[1] <- "machinery"
rownames(machinery) <- NULL
machinery <- machinery[,c(2,1)]
machinery <- merge(ALL, machinery, by = "Country")
machinery <- machinery[,c("Country", "machinery")]
machinery <- machinery[!duplicated(machinery),]

area_harvested <- data.frame(tapply(ALL$Area.Harvested, ALL$Country, mean, na.rm = TRUE))
area_harvested["Country"] <- rownames(area_harvested)
colnames(area_harvested)[1] <- "area_harvested"
rownames(area_harvested) <- NULL
area_harvested <- area_harvested[,c(2,1)]
area_harvested <- merge(ALL, area_harvested, by = "Country")
area_harvested <- area_harvested[,c("Country", "area_harvested")]
area_harvested <- area_harvested[!duplicated(area_harvested),]
machinery <- merge(machinery, area_harvested, by = "Country")
machinery$machinery.area <- machinery$machinery / machinery$area_harvested
machinery <- data.frame(machinery)
machinery <- machinery[machinery$area_harvested!=0,]
machinery$machinerygroup <- ifelse(machinery$machinery.area > mean(machinery$machinery.area, na.rm = TRUE), 1, 0)
ALL <- merge(machinery[,c("Country","machinery","machinerygroup")], ALL, by = "Country")


# ========================
# 2.2 GDPPC
# Note: 1 means GDPPC > mean
GDPPCcountry <- data.frame(tapply(ALL$GDPPC, ALL$Country, mean, na.rm = TRUE))
GDPPCcountry["Country"] <- rownames(GDPPCcountry)
colnames(GDPPCcountry)[1] <- "GDPPCcountry"
rownames(GDPPCcountry) <- NULL
GDPPCcountry <- GDPPCcountry[,c(2,1)]
GDPPCcountry <- merge(ALL, GDPPCcountry, by = "Country")
GDPPCcountry <- GDPPCcountry[,c("Country", "GDPPCcountry")]
GDPPCcountry <- GDPPCcountry[!duplicated(GDPPCcountry),]
GDPPCcountry[,"GDPPCcountry_group"] <- ifelse(GDPPCcountry$GDPPCcountry > mean(GDPPCcountry$GDPPCcountry, na.rm = TRUE), 1, 0)
ALL <- merge(GDPPCcountry, ALL, by = "Country")


# ========================
# 2.3. Import dependency
# Note: 1 means indicator > mean
IDRcountry <- data.frame(tapply(ALL$IDR, ALL$Country, mean, na.rm = TRUE))
IDRcountry["Country"] <- rownames(IDRcountry)
colnames(IDRcountry)[1] <- "IDRcountry"
rownames(IDRcountry) <- NULL
IDRcountry <- IDRcountry[,c(2,1)]
IDRcountry$IDRcountry_group <- ifelse(IDRcountry$IDRcountry > mean(IDRcountry$IDRcountry, na.rm = TRUE), 1, 0)
ALL <- merge(IDRcountry, ALL, by = "Country")


# ========================
# 2.4 SSR
# Note: 1 means SSR > mean

SSRcountry <- data.frame(tapply(ALL$SSR, ALL$Country, mean, na.rm = TRUE))
SSRcountry["Country"] <- rownames(SSRcountry)
colnames(SSRcountry)[1] <- "SSRcountry"
rownames(SSRcountry) <- NULL
SSRcountry <- SSRcountry[,c(2,1)]
SSRcountry[,"SSRcountry_group"] <- ifelse(SSRcountry$SSRcountry > mean(SSRcountry$SSRcountry, na.rm = TRUE), 1, 0)
ALL <- merge(SSRcountry, ALL, by = "Country")




# ========================= # ========================= # =========================
# Section 3. summary statistics, plots and log transform

# ========================= # =========================
# 3.1 summary statistics
# add more calculated variables
ALL$RSD <- (ALL$Production + ALL$Imports) / (ALL$Total.Consumption + ALL$Exports)

# delete missing
ALL <- ALL[complete.cases(ALL),]

summary(ALL)
stargazer(ALL, type = "html", nobs = T, mean.sd = TRUE, median = TRUE,
          iqr = TRUE, title="Statistic Description", digits=1,
          out="D:/food security/2021_revise/result_final/statistic description.htm")

write.csv(ALL, "D:/food security/2021_revise/data2020/ALL.csv")

# ========================= # =========================
# 3.2 plots
# plot world map for political risk, internal conflict and external conflict
library(rworldmap)
library(RColorBrewer)
colourPalette <- brewer.pal(7, "RdPu")
mapdata <- subset(ALL, select = c("Country", "Year", "Political_risk",
                                 "Internal_conflict", "External_conflict"))
mapdata <- aggregate(mapdata[,-(1:2)], by = list(mapdata$Country), FUN = mean)
names(mapdata) <- c("Country", "Political Risk", "Internal Conflict", "External Conflict")
# political risk plot
mapdata_pol = joinCountryData2Map(mapdata[,c("Country","Political Risk")],
                                  joinCode = "NAME", nameJoinColumn = "Country")
map_pol <- mapCountryData(mapdata_pol, nameColumnToPlot="Political Risk", addLegend=FALSE,
                          oceanCol = "lightblue", missingCountryCol= "white",
                          colourPalette = colourPalette)
do.call(addMapLegend, c(map_pol, legendLabels="all",
                        legendWidth=0.5, legendIntervals="data", legendMar=2))
# internal conflict plot
mapdata_int = joinCountryData2Map(mapdata[,c("Country","Internal Conflict")],
                                  joinCode = "NAME", nameJoinColumn = "Country")
map_int <- mapCountryData(mapdata_int, nameColumnToPlot="Internal Conflict", addLegend=FALSE,
                          oceanCol = "lightblue", missingCountryCol= "white",
                          colourPalette = colourPalette)
do.call(addMapLegend, c(map_int, legendLabels="all",
                        legendWidth=0.5, legendIntervals="data", legendMar=2))
# external conflict plot
mapdata_ext = joinCountryData2Map(mapdata[,c("Country","External Conflict")],
                                  joinCode = "NAME", nameJoinColumn = "Country")
map_ext <- mapCountryData(mapdata_ext, nameColumnToPlot="External Conflict", addLegend=FALSE,
                          oceanCol = "lightblue", missingCountryCol= "white",
                          colourPalette = colourPalette)
do.call(addMapLegend, c(map_ext, legendLabels="all",
                        legendWidth=0.5, legendIntervals="data", legendMar=2))


# ========================= # =========================
# 3.3
# plot of reserve ratio v.s. political risk, internal conflict and external conflict
library(ggplot2)
plotdata <- subset(ALL, select = c("Country", "Year", "Reserve.Ratio",
                                   "Political_risk", "External_conflict", "Internal_conflict"))
plotdata <- aggregate(plotdata[,-(1:2)], by = list(plotdata$Country), FUN = mean)
names(plotdata)[1] <- "Country"
ggplot(plotdata, aes(x=plotdata$Political_risk, y=plotdata$Reserve.Ratio)) +
  geom_point(shape=1) +
  stat_smooth(method = "lm", formula = y ~ poly(x, 2), color="black") +
  xlab("Political risk") + ylab("Reserve ratio") +
  theme(legend.title=element_blank(),
        legend.text = element_text(colour="black", size=15),
        legend.position = c(0.2, 0.85),
        legend.background = element_rect(fill=alpha('black', 0.0)),
        axis.title=element_text(size=15,face="bold"),
        text = element_text(family="STKaiti", size=15))

ggplot(plotdata, aes(x=plotdata$External_conflict, y=plotdata$Reserve.Ratio)) +
  geom_point(shape=1) +
  stat_smooth(method = "lm", formula = y ~ poly(x, 2), color="black") +
  xlab("External conflict") + ylab("Reserve ratio") +
  theme(legend.title=element_blank(),
        legend.text = element_text(colour="black", size=15),
        legend.position = c(0.2, 0.85),
        legend.background = element_rect(fill=alpha('black', 0.0)),
        axis.title=element_text(size=15,face="bold"),
        text = element_text(family="STKaiti", size=15))

ggplot(plotdata, aes(x=plotdata$Internal_conflict, y=plotdata$Reserve.Ratio)) +
  geom_point(shape=1) +
  stat_smooth(method = "lm", formula = y ~ poly(x, 2), color="black") +
  xlab("Internal conflict") + ylab("Reserve ratio") +
  theme(legend.title=element_blank(),
        legend.text = element_text(colour="black", size=15),
        legend.position = c(0.2, 0.85),
        legend.background = element_rect(fill=alpha('black', 0.0)),
        axis.title=element_text(size=15,face="bold"),
        text = element_text(family="STKaiti", size=15))

write.csv(plotdata, "D:/food security/2021_revise/data2020/plotdata.csv")

# ========================= # =========================
# 3.4 data log transformation

# function (log transform)
fun_log.transform <- function (x){
  log(1+x)
}

names(ALL)

# non dummy variables with positive value: do log transform
varnames <- colnames(ALL)[colnames(ALL) %in% c("Country", "SSRcountry", "SSRcountry_group",
                                              "IDRcountry", "IDRcountry_group", "GDPPCcountry",
                                              "GDPPCcountry_group", "machinerygroup",
                                              "Year", "SSR")]
non_varnames <- colnames(ALL)[!colnames(ALL) %in% c("Country", "SSRcountry", "SSRcountry_group",
                                                   "IDRcountry", "IDRcountry_group", "GDPPCcountry",
                                                   "GDPPCcountry_group", "machinerygroup",
                                                   "Year", "SSR")]
ALL <- cbind(ALL[,varnames], apply(ALL[,non_varnames], 2, fun_log.transform))

ALL <- arrange(ALL, Country, Year)



# ========================= # ========================= # =========================
# Section 4. Empirical Result
# ========================= # ========================
# 4.1 RV = indep + control (include grouping variables)

df_RV = subset(ALL, select = c("Country", "Year", "Reserve.Ratio",
               "Political_risk", "Internal_conflict", "External_conflict", "RSD",
                "Inland.water", "Area.Harvested", "Population", "Yield",
                "PPI", "num.disaster", "num.drought", "num.flood",
                "machinerygroup", "machinery", "GDPPCcountry_group", "GDPPC",
               "IDRcountry_group", "IDR", "SSRcountry_group", "SSR"))

# lag a year, for all independent variables
library(data.table)
varname <- colnames(df_RV)[!colnames(df_RV) %in% c("Country", "Year", "Reserve.Ratio")]
df_RV <- setDT(df_RV)[,paste0(varname):=lapply(.SD, shift), by = Country, .SDcols = varname]
detach("package:data.table", TRUE)

# ========================
# 4.1.1 use all data
ols_alldata_pol <- lm(Reserve.Ratio ~ Political_risk,
                      data = df_RV)
ols_alldata <- lm(Reserve.Ratio ~ Political_risk + 
                    Inland.water + Area.Harvested + Population + Yield + PPI + num.disaster + 
                    num.drought + num.flood, data = df_RV)

fixed.year_alldata_pol <- plm(Reserve.Ratio ~ Political_risk,
                              data = df_RV, index= c("Country","Year"), effect = "time", model="within")
fixed.year_alldata <- plm(Reserve.Ratio ~ Political_risk + 
                            Inland.water + Area.Harvested + Population + Yield + PPI + num.disaster + 
                            num.drought + num.flood, data = df_RV, index= c("Country","Year"),effect = "time", model="within")

# rand_all_data_pol <- plm(Reserve.Ratio ~ Political_risk,
#                          data = df_RV, index= c("Country","Year"), model="random")
# rand_alldata <- plm(Reserve.Ratio ~ Political_risk + 
#                     Inland.water + Area.Harvested + Population + Yield + PPI + num.disaster + 
#                     num.drought + num.flood, data = df_RV, index= c("Country","Year"), model="random")
# 
# phtest(fixed.year_alldata_pol, rand_all_data_pol)
# phtest(fixed.year_alldata, rand_alldata)
# p-value < 0.05, use fixed effects

stargazer(ols_alldata_pol, ols_alldata,
          fixed.year_alldata_pol, fixed.year_alldata,
          column.labels = c("pool", "fix year"),
          column.separate = c(2,2),
          ord.intercepts = TRUE,
          type = "html", title = "alldata",
          omit.stat = c("adj.rsq" ,"f"),
          out = "D:/food security/2021_revise/result_final/alldata.htm")

# ========================
# 4.1.2 grouping: machinery
df_RV.machineryhigh <- subset(df_RV, df_RV$machinerygroup == 1)
df_RV.machinerylow <- subset(df_RV, df_RV$machinerygroup == 0)


ols_machineryhigh <- lm(Reserve.Ratio ~ Political_risk + 
                          Inland.water + Area.Harvested + Population +
                          Yield + PPI + num.disaster + 
                          num.drought + num.flood,
                          data = df_RV.machineryhigh)

ols_machinerylow <- lm(Reserve.Ratio ~ Political_risk + 
                         Inland.water + Area.Harvested + Population +
                         Yield + PPI + num.disaster + 
                         num.drought + num.flood,
                         data = df_RV.machinerylow)


fixed.year_machineryhigh <- plm(Reserve.Ratio ~ Political_risk + 
                                  Inland.water + Area.Harvested + Population +
                                  Yield + PPI + num.disaster + 
                                  num.drought + num.flood,
                                  data = df_RV.machineryhigh, index= c("Country","Year"),
                                  effect = "time", model="within")

fixed.year_machinerylow <- plm(Reserve.Ratio ~ Political_risk + 
                                 Inland.water + Area.Harvested + Population +
                                 Yield + PPI + num.disaster + 
                                 num.drought + num.flood,
                                 data = df_RV.machinerylow, index= c("Country","Year"),
                                 effect = "time", model="within")


stargazer(ols_machineryhigh, ols_machinerylow,
          fixed.year_machineryhigh, fixed.year_machinerylow,
          type = "html", title = "machinery group for reserve ratio",
          omit.stat = c("adj.rsq" ,"f"),
          out = "D:/food security/2021_revise/result_final/machinery.htm")


# ========================
# 4.1.3. grouping: GDPPC
df_RV.GDPPChigh <- subset(df_RV, df_RV$GDPPCcountry_group == 1)
df_RV.GDPPClow <- subset(df_RV, df_RV$GDPPCcountry_group == 0)


ols_GDPPChigh <- lm(Reserve.Ratio ~ Political_risk + 
                       Inland.water + Area.Harvested + Population +
                       Yield + PPI + num.disaster + 
                       num.drought + num.flood,
                     data = df_RV.GDPPChigh)
ols_GDPPClow <- lm(Reserve.Ratio ~ Political_risk + 
                      Inland.water + Area.Harvested + Population +
                      Yield + PPI + num.disaster + 
                      num.drought + num.flood,
                    data = df_RV.GDPPClow)

fixed.year_GDPPChigh <- plm(Reserve.Ratio ~ Political_risk + 
                               Inland.water + Area.Harvested + Population +
                               Yield + PPI + num.disaster + 
                               num.drought + num.flood,
                             data = df_RV.GDPPChigh, index= c("Country","Year"),
                             effect = "time", model="within")

fixed.year_GDPPClow <- plm(Reserve.Ratio ~ Political_risk + 
                              Inland.water + Area.Harvested + Population +
                              Yield + PPI + num.disaster + 
                              num.drought + num.flood,
                            data = df_RV.GDPPClow, index= c("Country","Year"),
                            effect = "time", model="within")

stargazer(ols_GDPPChigh, ols_GDPPClow,
          fixed.year_GDPPChigh, fixed.year_GDPPClow,
          type = "html", title = "GDPPC group for reserve ratio",
          omit.stat = c("adj.rsq" ,"f"),
          out = "D:/food security/2021_revise/result_final/GDPPC.htm")


# ========================
# 4.1.4. grouping: Import dependency
df_RV.IDRhigh <- subset(df_RV, df_RV$IDRcountry_group == 1)
df_RV.IDRlow <- subset(df_RV, df_RV$IDRcountry_group == 0)

ols_IDRhigh <- lm(Reserve.Ratio ~ Political_risk + 
                       Inland.water + Area.Harvested + Population +
                       Yield + PPI + num.disaster + 
                       num.drought + num.flood,
                       data = df_RV.IDRhigh)
ols_IDRlow <- lm(Reserve.Ratio ~ Political_risk + 
                      Inland.water + Area.Harvested + Population +
                      Yield + PPI + num.disaster + 
                      num.drought + num.flood,
                      data = df_RV.IDRlow)

fixed.year_IDRhigh <- plm(Reserve.Ratio ~ Political_risk + 
                               Inland.water + Area.Harvested + Population +
                               Yield + PPI + num.disaster + 
                               num.drought + num.flood,
                               data = df_RV.IDRhigh, index= c("Country","Year"),
                               effect = "time", model="within")

fixed.year_IDRlow <- plm(Reserve.Ratio ~ Political_risk + 
                              Inland.water + Area.Harvested + Population +
                              Yield + PPI + num.disaster + 
                              num.drought + num.flood,
                              data = df_RV.IDRlow, index= c("Country","Year"),
                              effect = "time", model="within")


stargazer(ols_IDRhigh, ols_IDRlow,
          fixed.year_IDRhigh, fixed.year_IDRlow,
          type = "html", title = "IDR group for reserve ratio",
          omit.stat = c("adj.rsq" ,"f"),
          out = "D:/food security/2021_revise/result_final/IDR.htm")


# ========================
# 4.1.5. grouping: SSR
df_RV.SSRhigh <- subset(df_RV, df_RV$SSRcountry_group == 1)
df_RV.SSRlow <- subset(df_RV, df_RV$SSRcountry_group == 0)

ols_SSRhigh <- lm(Reserve.Ratio ~ Political_risk + 
                     Inland.water + Area.Harvested + Population +
                     Yield + PPI + num.disaster + 
                     num.drought + num.flood,
                   data = df_RV.SSRhigh)
ols_SSRlow <- lm(Reserve.Ratio ~ Political_risk + 
                    Inland.water + Area.Harvested + Population +
                    Yield + PPI + num.disaster + 
                    num.drought + num.flood,
                  data = df_RV.SSRlow)

fixed.year_SSRhigh <- plm(Reserve.Ratio ~ Political_risk + 
                             Inland.water + Area.Harvested + Population +
                             Yield + PPI + num.disaster + 
                             num.drought + num.flood,
                           data = df_RV.SSRhigh, index= c("Country","Year"),
                           effect = "time", model="within")

fixed.year_SSRlow <- plm(Reserve.Ratio ~ Political_risk + 
                            Inland.water + Area.Harvested + Population +
                            Yield + PPI + num.disaster + 
                            num.drought + num.flood,
                          data = df_RV.SSRlow, index= c("Country","Year"),
                          effect = "time", model="within")


stargazer(ols_SSRhigh, ols_SSRlow,
          fixed.year_SSRhigh, fixed.year_SSRlow,
          type = "html", title = "SSR group for reserve ratio",
          omit.stat = c("adj.rsq" ,"f"),
          out = "D:/food security/2021_revise/result_final/SSR.htm")

# ========================
# 4.1.6 indep: external/internal
ols_RV_inter <- lm(Reserve.Ratio ~ Internal_conflict,
                   data = df_RV)

ols_pol_RV_inter <- lm(Reserve.Ratio ~ Internal_conflict +
                         Inland.water + Area.Harvested + Population +
                         Yield + PPI + num.disaster + 
                         num.drought + num.flood,
                         data = df_RV)

fixed.year_RV_inter <- plm(Reserve.Ratio ~ Internal_conflict,
                           data = df_RV, index= c("Country","Year"),
                           effect = "time", model="within")

fixed.year_pol_RV_inter <- plm(Reserve.Ratio ~ Internal_conflict + 
                                 Inland.water + Area.Harvested + Population +
                                 Yield + PPI + num.disaster + 
                                 num.drought + num.flood,
                                 data = df_RV, index= c("Country","Year"),
                                 effect = "time", model="within")


ols_RV_exter <- lm(Reserve.Ratio ~ External_conflict,
                   data = df_RV)

ols_pol_RV_exter <- lm(Reserve.Ratio ~ External_conflict + 
                         Inland.water + Area.Harvested + Population +
                         Yield + PPI + num.disaster + 
                         num.drought + num.flood,
                         data = df_RV)

fixed.year_RV_exter <- plm(Reserve.Ratio ~ External_conflict,
                           data = df_RV, index= c("Country","Year"),
                           effect = "time", model="within")

fixed.year_pol_RV_exter <- plm(Reserve.Ratio ~ External_conflict +
                                 Inland.water + Area.Harvested + Population +
                                 Yield + PPI + num.disaster + 
                                 num.drought + num.flood,
                                 data = df_RV, index= c("Country","Year"),
                                 effect = "time", model="within")



ols_RV_exter_inter <- lm(Reserve.Ratio ~  External_conflict + Internal_conflict,
                         data = df_RV)

ols_pol_RV_exter_inter <- lm(Reserve.Ratio ~ External_conflict + Internal_conflict +
                               Inland.water + Area.Harvested + Population +
                               Yield + PPI + num.disaster + 
                               num.drought + num.flood,
                             data = df_RV)

fixed.year_RV_exter_inter <- plm(Reserve.Ratio ~ External_conflict + Internal_conflict,
                                 data = df_RV, index= c("Country","Year"),
                                 effect = "time", model="within")

fixed.year_pol_RV_exter_inter <- plm(Reserve.Ratio ~ External_conflict + Internal_conflict  +
                                       Inland.water + Area.Harvested + Population +
                                       Yield + PPI + num.disaster + 
                                       num.drought + num.flood,
                                     data = df_RV, index= c("Country","Year"),
                                     effect = "time", model="within")


stargazer(ols_RV_exter, ols_RV_inter, ols_RV_exter_inter,
          ols_pol_RV_exter, ols_pol_RV_inter, ols_pol_RV_exter_inter,
          fixed.year_RV_exter, fixed.year_RV_inter, fixed.year_RV_exter_inter,
          fixed.year_pol_RV_exter, fixed.year_pol_RV_inter, fixed.year_pol_RV_exter_inter,
          type = "html", title = "Reserve ratio = exter/inter + control",
          omit.stat = c("adj.rsq" ,"f"),
          out = "D:/food security/2021_revise/result_final/RV_inexter.htm")


# ========================
# 4.1.7 indep: RSD
ols_RV_RSD <- lm(Reserve.Ratio ~ RSD,
                 data = df_RV)

ols_pol_RV_RSD <- lm(Reserve.Ratio ~ RSD + Inland.water + 
                       Area.Harvested + Population +
                       Yield + PPI + num.disaster + 
                       num.drought + num.flood,
                     data = df_RV)
fixed.year_RV_RSD <- plm(Reserve.Ratio ~ RSD,
                         data = df_RV, index= c("Country","Year"),
                         effect = "time", model="within")

fixed.year_pol_RV_RSD <- plm(Reserve.Ratio ~ RSD + Inland.water + 
                               Area.Harvested + Population +
                               Yield + PPI + num.disaster + 
                               num.drought + num.flood,
                             data = df_RV, index= c("Country","Year"),
                             effect = "time", model="within")
stargazer(ols_RV_RSD, ols_pol_RV_RSD,
          fixed.year_RV_RSD, fixed.year_pol_RV_RSD,
          type = "html", title = "RV = RSD + control",
          omit.stat = c("adj.rsq" ,"f"),
          out = "D:/food security/2021_revise/result_final/RV_RSD.htm")



# ========================= # ========================
# 4.2 Production = indep + control

df_Pro = subset(ALL, select = c("Country", "Year", "Production",
                "Internal_conflict", "External_conflict",
                "Inland.water", "Area.Harvested", "Population", "Yield",
                "PPI", "num.disaster", "num.drought", "num.flood"))

# lag a year, for all independent variables
library(data.table)
varname <- colnames(df_Pro)[!colnames(df_Pro) %in% c("Country", "Year", "Production")]
df_Pro <- setDT(df_Pro)[,paste0(varname):=lapply(.SD, shift), by = Country, .SDcols = varname]
detach("package:data.table", TRUE)

# ========================
# 4.2.1 indep: internal conflict
ols_production_inter <- lm(Production ~ Internal_conflict,
                           data = df_Pro)
ols_pol_production_inter <- lm(Production ~ Internal_conflict + Inland.water + 
                                 Area.Harvested + Population +
                                 Yield + PPI + num.disaster + 
                                 num.drought + num.flood,
                               data = df_Pro)
fixed.year_production_inter <- plm(Production ~ Internal_conflict,
                                   data = df_Pro, index= c("Country","Year"),
                                   effect = "time", model="within")

fixed.year_pol_production_inter <- plm(Production ~ Internal_conflict + Inland.water + 
                                         Area.Harvested + Population +
                                         Yield + PPI + num.disaster + 
                                         num.drought + num.flood,
                                       data = df_Pro, index= c("Country","Year"),
                                       effect = "time", model="within")

# ========================
# 4.2.2 indep: external conflict
ols_production_exter <- lm(Production ~ External_conflict,
                           data = df_Pro)

ols_pol_production_exter <- lm(Production ~ External_conflict + Inland.water + 
                                 Area.Harvested + Population +
                                 Yield + PPI + num.disaster + 
                                 num.drought + num.flood,
                               data = df_Pro)

fixed.year_production_exter <- plm(Production ~ External_conflict,
                                   data = df_Pro, index= c("Country","Year"),
                                   effect = "time", model="within")

fixed.year_pol_production_exter <- plm(Production ~ External_conflict + Inland.water + 
                                         Area.Harvested + Population +
                                         Yield + PPI + num.disaster + 
                                         num.drought + num.flood,
                                       data = df_Pro, index= c("Country","Year"),
                                       effect = "time", model="within")



# ========================= # ========================
# 4.3 Imports = indep + control

df_Imp = subset(ALL, select = c("Country", "Year", "Imports",
                "Internal_conflict", "External_conflict",
                "Inland.water", "Area.Harvested", "Population", "Yield",
                "PPI", "num.disaster", "num.drought", "num.flood"))

# lag a year, for all independent variables
library(data.table)
varname <- colnames(df_Imp)[!colnames(df_Imp) %in% c("Country", "Year", "Imports")]
df_Imp <- setDT(df_Imp)[,paste0(varname):=lapply(.SD, shift), by = Country, .SDcols = varname]
detach("package:data.table", TRUE)


# ========================
# 4.3.1 indep: internal conflict
ols_import_inter <- lm(Imports ~ Internal_conflict,
                       data = df_Imp)
ols_pol_import_inter <- lm(Imports ~ Internal_conflict + Inland.water + 
                             Area.Harvested + Population +
                             Yield + PPI + num.disaster + 
                             num.drought + num.flood,
                           data = df_Imp)
fixed.year_import_inter <- plm(Imports ~ Internal_conflict,
                               data = df_Imp, index= c("Country","Year"),
                               effect = "time", model="within")

fixed.year_pol_import_inter <- plm(Imports ~ Internal_conflict + Inland.water + 
                                     Area.Harvested + Population +
                                     Yield + PPI + num.disaster + 
                                     num.drought + num.flood,
                                   data = df_Imp, index= c("Country","Year"),
                                   effect = "time", model="within")

# ========================
# 4.3.2 indep: external conflict
ols_import_exter <- lm(Imports ~ External_conflict,
                       data = df_Imp)
ols_pol_import_exter <- lm(Imports ~ External_conflict + Inland.water + 
                             Area.Harvested + Population +
                             Yield + PPI + num.disaster + 
                             num.drought + num.flood,
                           data = df_Imp)
fixed.year_import_exter <- plm(Imports ~ External_conflict,
                               data = df_Imp, index= c("Country","Year"),
                               effect = "time", model="within")
fixed.year_pol_import_exter <- plm(Imports ~ External_conflict + Inland.water + 
                                     Area.Harvested + Population +
                                     Yield + PPI + num.disaster + 
                                     num.drought + num.flood,
                                   data = df_Imp, index= c("Country","Year"),
                                   effect = "time", model="within")


# ========================= # ========================
# 4.4 Exports = indep + control
df_Exp = subset(ALL, select = c("Country", "Year", "Exports",
                "Internal_conflict", "External_conflict",
                "Inland.water", "Area.Harvested", "Population", "Yield",
                "PPI", "num.disaster", "num.drought", "num.flood"))

# lag a year, for all independent variables
library(data.table)
varname <- colnames(df_Exp)[!colnames(df_Exp) %in% c("Country", "Year", "Exports")]
df_Exp <- setDT(df_Exp)[,paste0(varname):=lapply(.SD, shift), by = Country, .SDcols = varname]
detach("package:data.table", TRUE)

# ========================
# 4.4.1 indep: internal conflict
ols_export_inter <- lm(Exports ~ Internal_conflict,
                       data = df_Exp)
ols_pol_export_inter <- lm(Exports ~ Internal_conflict + Inland.water + 
                             Area.Harvested + Population +
                             Yield + PPI + num.disaster + 
                             num.drought + num.flood,
                           data = df_Exp)
fixed.year_export_inter <- plm(Exports ~ Internal_conflict,
                               data = df_Exp, index= c("Country","Year"),
                               effect = "time", model="within")
fixed.year_pol_export_inter <- plm(Exports ~ Internal_conflict + Inland.water + 
                                     Area.Harvested + Population +
                                     Yield + PPI + num.disaster + 
                                     num.drought + num.flood,
                                   data = df_Exp, index= c("Country","Year"),
                                   effect = "time", model="within")

# ========================
# 4.4.2 indep: external conflict
ols_export_exter <- lm(Exports ~ External_conflict,
                       data = df_Exp)
ols_pol_export_exter <- lm(Exports ~ External_conflict + Inland.water + 
                             Area.Harvested + Population +
                             Yield + PPI + num.disaster + 
                             num.drought + num.flood,
                           data = df_Exp)
fixed.year_export_exter <- plm(Exports ~ External_conflict,
                               data = df_Exp, index= c("Country","Year"),
                               effect = "time", model="within")
fixed.year_pol_export_exter <- plm(Exports ~ External_conflict + Inland.water + 
                                     Area.Harvested + Population +
                                     Yield + PPI + num.disaster + 
                                     num.drought + num.flood,
                                   data = df_Exp, index= c("Country","Year"),
                                   effect = "time", model="within")


# ========================= # ========================
# 4.5 Consumption = indep + control
df_Con = subset(ALL, select = c("Country", "Year", "Total.Consumption",
                "Internal_conflict", "External_conflict",
                "Inland.water", "Area.Harvested", "Population", "Yield",
                "PPI", "num.disaster", "num.drought", "num.flood"))

# lag a year, for all independent variables
library(data.table)
varname <- colnames(df_Con)[!colnames(df_Con) %in% c("Country", "Year", "Total.Consumption")]
df_Con <- setDT(df_Con)[,paste0(varname):=lapply(.SD, shift), by = Country, .SDcols = varname]
detach("package:data.table", TRUE)

# ========================
# 4.5.1 indep: internal conflict
ols_consumption_inter <- lm(Total.Consumption ~ Internal_conflict,
                            data = df_Con)
ols_pol_consumption_inter <- lm(Total.Consumption ~ Internal_conflict + Inland.water + 
                                  Area.Harvested + Population +
                                  Yield + PPI + num.disaster + 
                                  num.drought + num.flood,
                                data = df_Con)
fixed.year_consumption_inter <- plm(Total.Consumption ~ Internal_conflict,
                                    data = df_Con, index= c("Country","Year"),
                                    effect = "time", model="within")
fixed.year_pol_consumption_inter <- plm(Total.Consumption ~ Internal_conflict + Inland.water + 
                                          Area.Harvested + Population +
                                          Yield + PPI + num.disaster + 
                                          num.drought + num.flood,
                                        data = df_Con, index= c("Country","Year"),
                                        effect = "time", model="within")

# ========================
# 4.5.2 indep: external conflict
ols_consumption_exter <- lm(Total.Consumption ~ External_conflict,
                            data = df_Con)
ols_pol_consumption_exter <- lm(Total.Consumption ~ External_conflict + Inland.water + 
                                  Area.Harvested + Population +
                                  Yield + PPI + num.disaster + 
                                  num.drought + num.flood,
                                data = df_Con)
fixed.year_consumption_exter <- plm(Total.Consumption ~ External_conflict,
                                    data = df_Con, index= c("Country","Year"),
                                    effect = "time", model="within")
fixed.year_pol_consumption_exter <- plm(Total.Consumption ~ External_conflict + Inland.water + 
                                          Area.Harvested + Population +
                                          Yield + PPI + num.disaster + 
                                          num.drought + num.flood,
                                        data = df_Con, index= c("Country","Year"),
                                        effect = "time", model="within")



stargazer(ols_production_exter, ols_pol_production_exter,
          ols_import_exter, ols_pol_import_exter,
          ols_export_exter, ols_pol_export_exter,
          ols_consumption_exter, ols_pol_consumption_exter,
          fixed.year_production_exter, fixed.year_pol_production_exter,
          fixed.year_import_exter, fixed.year_pol_import_exter,
          fixed.year_export_exter, fixed.year_pol_export_exter,
          fixed.year_consumption_exter, fixed.year_pol_consumption_exter,
          type = "html", title = "Production/imports/exports/consumption = exter + control",
          omit.stat = c("adj.rsq" ,"f"),
          out = "D:/food security/2021_revise/result_final/other_exter.htm")


stargazer(ols_production_inter, ols_pol_production_inter,
          ols_import_inter, ols_pol_import_inter,
          ols_export_inter, ols_pol_export_inter,
          ols_consumption_inter, ols_pol_consumption_inter,
          fixed.year_production_inter, fixed.year_pol_production_inter,
          fixed.year_import_inter, fixed.year_pol_import_inter,
          fixed.year_export_inter, fixed.year_pol_export_inter,
          fixed.year_consumption_inter, fixed.year_pol_consumption_inter,
          type = "html", title = "Production/imports/exports/consumption = inter + control",
          omit.stat = c("adj.rsq" ,"f"),
          out = "D:/food security/2021_revise/result_final/other_inter.htm")




# ========================= # ========================= # =========================
# Section 5. Robustness test
# ========================= # ========================= 
# 5.1 robust for grouping variables
# =========================
# 5.1.1 machinery
grp_ols_machinery <- lm(Reserve.Ratio ~ Political_risk * machinery
                          + Inland.water + Area.Harvested + Population
                          + Yield + PPI + num.disaster 
                          + num.drought + num.flood,
                          data = df_RV)

grp_ols_machinery_dmy <- lm(Reserve.Ratio ~ Political_risk * (machinerygroup == 1)
                            + Inland.water + Area.Harvested + Population
                            + Yield + PPI + num.disaster 
                            + num.drought + num.flood,
                              data = df_RV)


grp_fixed.year_machinery <- plm(Reserve.Ratio ~ Political_risk * machinery
                                 + Inland.water + Area.Harvested + Population
                                 + Yield + PPI + num.disaster 
                                 + num.drought + num.flood,
                                  data = df_RV, index= c("Country","Year"), effect = "time", model="within")

grp_fixed.year_machinery_dmy <- plm(Reserve.Ratio ~ Political_risk * (machinerygroup == 1)
                                    + Inland.water + Area.Harvested + Population
                                    + Yield + PPI + num.disaster 
                                    + num.drought + num.flood,
                                      data = df_RV, index= c("Country","Year"), effect = "time", model="within")


stargazer(grp_ols_machinery, grp_ols_machinery_dmy,
          grp_fixed.year_machinery, grp_fixed.year_machinery_dmy,
          type = "html", title = "appendix machinery group",
          omit.stat = c("adj.rsq" ,"f"),
          out = "D:/food security/2021_revise/robust_grp/grp_machinery.htm")

# =========================
# 5.1.2 economical safety
grp_ols_GDPPC <- lm(Reserve.Ratio ~ Political_risk * GDPPC
                    + Inland.water + Area.Harvested + Population
                    + Yield + PPI + num.disaster 
                    + num.drought + num.flood,
                    data = df_RV)
grp_ols_GDPPC_dmy <- lm(Reserve.Ratio ~ Political_risk * (GDPPCcountry_group == 1)
                        + Inland.water + Area.Harvested + Population
                        + Yield + PPI + num.disaster 
                        + num.drought + num.flood,
                        data = df_RV)

grp_fixed.year_GDPPC <- plm(Reserve.Ratio ~ Political_risk * GDPPC
                            + Inland.water + Area.Harvested + Population
                            + Yield + PPI + num.disaster 
                            + num.drought + num.flood,
                            data = df_RV, index= c("Country","Year"),effect = "time", model="within")

grp_fixed.year_GDPPC_dmy <- plm(Reserve.Ratio ~ Political_risk * (GDPPCcountry_group == 1)
                                + Inland.water + Area.Harvested + Population
                                + Yield + PPI + num.disaster 
                                + num.drought + num.flood,
                                data = df_RV, index= c("Country","Year"),effect = "time", model="within")

stargazer(grp_ols_GDPPC, grp_ols_GDPPC_dmy,
          grp_fixed.year_GDPPC, grp_fixed.year_GDPPC_dmy,
          type = "html", title = "appendix GDPPC group",
          omit.stat = c("adj.rsq" ,"f"),
          out = "D:/food security/2021_revise/robust_grp/grp_GDPPC.htm")

# =========================
# 5.1.3 Import dependency
grp_ols_IDR <- lm(Reserve.Ratio ~ Political_risk * IDR
                  + Inland.water + Area.Harvested + Population
                  + Yield + PPI + num.disaster 
                  + num.drought + num.flood,
                  data = df_RV)
grp_ols_IDR_dmy <- lm(Reserve.Ratio ~ Political_risk * (IDRcountry_group == 1)
                      + Inland.water + Area.Harvested + Population
                      + Yield + PPI + num.disaster 
                      + num.drought + num.flood,
                      data = df_RV)

grp_fixed.year_IDR <- plm(Reserve.Ratio ~ Political_risk * IDR
                          + Inland.water + Area.Harvested + Population
                          + Yield + PPI + num.disaster 
                          + num.drought + num.flood,
                          data = df_RV, index= c("Country","Year"),effect = "time", model="within")

grp_fixed.year_IDR_dmy <- plm(Reserve.Ratio ~ Political_risk * (IDRcountry_group == 1)
                              + Inland.water + Area.Harvested + Population
                              + Yield + PPI + num.disaster 
                              + num.drought + num.flood,
                              data = df_RV, index= c("Country","Year"),effect = "time", model="within")


stargazer(grp_ols_IDR, grp_ols_IDR_dmy,
          grp_fixed.year_IDR, grp_fixed.year_IDR_dmy,
          type = "html", title = "appendix IDR group",
          omit.stat = c("adj.rsq" ,"f"),
          out = "D:/food security/2021_revise/robust_grp/grp_IDR.htm")

# =========================
# 5.1.4 SSR
grp_ols_SSR <- lm(Reserve.Ratio ~ Political_risk * SSR
                  + Inland.water + Area.Harvested + Population
                  + Yield + PPI + num.disaster 
                  + num.drought + num.flood,
                  data = df_RV)
grp_ols_SSR_dmy <- lm(Reserve.Ratio ~ Political_risk * (SSRcountry_group == 1)
                      + Inland.water + Area.Harvested + Population
                      + Yield + PPI + num.disaster 
                      + num.drought + num.flood,
                      data = df_RV)

grp_fixed.year_SSR <- plm(Reserve.Ratio ~ Political_risk * SSR
                          + Inland.water + Area.Harvested + Population
                          + Yield + PPI + num.disaster 
                          + num.drought + num.flood,
                          data = df_RV, index= c("Country","Year"),effect = "time", model="within")

grp_fixed.year_SSR_dmy <- plm(Reserve.Ratio ~ Political_risk * (SSRcountry_group == 1)
                              + Inland.water + Area.Harvested + Population
                              + Yield + PPI + num.disaster 
                              + num.drought + num.flood,
                              data = df_RV, index= c("Country","Year"),effect = "time", model="within")


stargazer(grp_ols_SSR, grp_ols_SSR_dmy,
          grp_fixed.year_SSR, grp_fixed.year_SSR_dmy,
          type = "html", title = "appendix SSR group",
          omit.stat = c("adj.rsq" ,"f"),
          out = "D:/food security/2021_revise/robust_grp/grp_SSR.htm")


# ========================= # =========================
# 5.2 lag three years for independent variables
lag3_df_RV = subset(ALL, select = c("Country", "Year", "Reserve.Ratio",
                       "Political_risk", "Internal_conflict", "External_conflict", "RSD",
                       "Inland.water", "Area.Harvested", "Population", "Yield",
                       "PPI", "num.disaster", "num.drought", "num.flood",
                       "machinerygroup", "machinery", "GDPPCcountry_group", "GDPPC",
                       "IDRcountry_group", "IDR", "SSRcountry_group", "SSR"))
# lag 3 years
library(data.table)
varname <- colnames(lag3_df_RV)[!colnames(lag3_df_RV) %in% c("Country", "Year", "Reserve.Ratio")]
lag3_df_RV <- setDT(lag3_df_RV)[,paste0(varname):=lapply(.SD, function(x) shift(x,n=3)), by = Country, .SDcols = varname]
detach("package:data.table", TRUE)

# ========================
# 5.2.1 use all data
lag3_ols_alldata_pol <- lm(Reserve.Ratio ~ Political_risk,
                          data = lag3_df_RV)
lag3_ols_alldata <- lm(Reserve.Ratio ~ Political_risk + 
                        Inland.water + Area.Harvested + Population + Yield + PPI + num.disaster + 
                        num.drought + num.flood, data = lag3_df_RV)

lag3_fixed.year_alldata_pol <- plm(Reserve.Ratio ~ Political_risk,
                                  data = lag3_df_RV, index= c("Country","Year"), effect = "time", model="within")
lag3_fixed.year_alldata <- plm(Reserve.Ratio ~ Political_risk + 
                                Inland.water + Area.Harvested + Population + Yield + PPI + num.disaster + 
                                num.drought + num.flood, data = lag3_df_RV, index= c("Country","Year"),effect = "time", model="within")

stargazer(lag3_ols_alldata_pol, lag3_ols_alldata,
          lag3_fixed.year_alldata_pol, lag3_fixed.year_alldata,
          column.labels = c("pool", "fix year"),
          column.separate = c(2,2),
          ord.intercepts = TRUE,
          type = "html", title = "alldata",
          omit.stat = c("adj.rsq" ,"f"),
          out = "D:/food security/2021_revise/robust_lag3/alldata.htm")

# ========================
# 5.2.2 grouping
lag3_df_RV.machineryhigh <- subset(lag3_df_RV, lag3_df_RV$machinerygroup == 1)
lag3_df_RV.machinerylow <- subset(lag3_df_RV, lag3_df_RV$machinerygroup == 0)


lag3_ols_machineryhigh <- lm(Reserve.Ratio ~ Political_risk + 
                              Inland.water + Area.Harvested + Population +
                              Yield + PPI + num.disaster + 
                              num.drought + num.flood,
                            data = lag3_df_RV.machineryhigh)

lag3_ols_machinerylow <- lm(Reserve.Ratio ~ Political_risk + 
                             Inland.water + Area.Harvested + Population +
                             Yield + PPI + num.disaster + 
                             num.drought + num.flood,
                           data = lag3_df_RV.machinerylow)


lag3_fixed.year_machineryhigh <- plm(Reserve.Ratio ~ Political_risk + 
                                      Inland.water + Area.Harvested + Population +
                                      Yield + PPI + num.disaster + 
                                      num.drought + num.flood,
                                    data = lag3_df_RV.machineryhigh, index= c("Country","Year"),
                                    effect = "time", model="within")

lag3_fixed.year_machinerylow <- plm(Reserve.Ratio ~ Political_risk + 
                                     Inland.water + Area.Harvested + Population +
                                     Yield + PPI + num.disaster + 
                                     num.drought + num.flood,
                                   data = lag3_df_RV.machinerylow, index= c("Country","Year"),
                                   effect = "time", model="within")


stargazer(lag3_ols_machineryhigh, lag3_ols_machinerylow,
          lag3_fixed.year_machineryhigh, lag3_fixed.year_machinerylow,
          type = "html", title = "machinery group for reserve ratio",
          omit.stat = c("adj.rsq" ,"f"),
          out = "D:/food security/2021_revise/robust_lag3/machinery.htm")


lag3_df_RV.GDPPChigh <- subset(lag3_df_RV, lag3_df_RV$GDPPCcountry_group == 1)
lag3_df_RV.GDPPClow <- subset(lag3_df_RV, lag3_df_RV$GDPPCcountry_group == 0)


lag3_ols_GDPPChigh <- lm(Reserve.Ratio ~ Political_risk + 
                          Inland.water + Area.Harvested + Population +
                          Yield + PPI + num.disaster + 
                          num.drought + num.flood,
                        data = lag3_df_RV.GDPPChigh)
lag3_ols_GDPPClow <- lm(Reserve.Ratio ~ Political_risk + 
                         Inland.water + Area.Harvested + Population +
                         Yield + PPI + num.disaster + 
                         num.drought + num.flood,
                       data = lag3_df_RV.GDPPClow)

lag3_fixed.year_GDPPChigh <- plm(Reserve.Ratio ~ Political_risk + 
                                  Inland.water + Area.Harvested + Population +
                                  Yield + PPI + num.disaster + 
                                  num.drought + num.flood,
                                data = lag3_df_RV.GDPPChigh, index= c("Country","Year"),
                                effect = "time", model="within")

lag3_fixed.year_GDPPClow <- plm(Reserve.Ratio ~ Political_risk + 
                                 Inland.water + Area.Harvested + Population +
                                 Yield + PPI + num.disaster + 
                                 num.drought + num.flood,
                               data = lag3_df_RV.GDPPClow, index= c("Country","Year"),
                               effect = "time", model="within")

stargazer(lag3_ols_GDPPChigh, lag3_ols_GDPPClow,
          lag3_fixed.year_GDPPChigh, lag3_fixed.year_GDPPClow,
          type = "html", title = "GDPPC group for reserve ratio",
          omit.stat = c("adj.rsq" ,"f"),
          out = "D:/food security/2021_revise/robust_lag3/GDPPC.htm")


lag3_df_RV.IDRhigh <- subset(lag3_df_RV, lag3_df_RV$IDRcountry_group == 1)
lag3_df_RV.IDRlow <- subset(lag3_df_RV, lag3_df_RV$IDRcountry_group == 0)

lag3_ols_IDRhigh <- lm(Reserve.Ratio ~ Political_risk + 
                        Inland.water + Area.Harvested + Population +
                        Yield + PPI + num.disaster + 
                        num.drought + num.flood,
                      data = lag3_df_RV.IDRhigh)
lag3_ols_IDRlow <- lm(Reserve.Ratio ~ Political_risk + 
                       Inland.water + Area.Harvested + Population +
                       Yield + PPI + num.disaster + 
                       num.drought + num.flood,
                     data = lag3_df_RV.IDRlow)

lag3_fixed.year_IDRhigh <- plm(Reserve.Ratio ~ Political_risk + 
                                Inland.water + Area.Harvested + Population +
                                Yield + PPI + num.disaster + 
                                num.drought + num.flood,
                              data = lag3_df_RV.IDRhigh, index= c("Country","Year"),
                              effect = "time", model="within")

lag3_fixed.year_IDRlow <- plm(Reserve.Ratio ~ Political_risk + 
                               Inland.water + Area.Harvested + Population +
                               Yield + PPI + num.disaster + 
                               num.drought + num.flood,
                             data = lag3_df_RV.IDRlow, index= c("Country","Year"),
                             effect = "time", model="within")


stargazer(lag3_ols_IDRhigh, lag3_ols_IDRlow,
          lag3_fixed.year_IDRhigh, lag3_fixed.year_IDRlow,
          type = "html", title = "IDR group for reserve ratio",
          omit.stat = c("adj.rsq" ,"f"),
          out = "D:/food security/2021_revise/robust_lag3/IDR.htm")



lag3_df_RV.SSRhigh <- subset(lag3_df_RV, lag3_df_RV$SSRcountry_group == 1)
lag3_df_RV.SSRlow <- subset(lag3_df_RV, lag3_df_RV$SSRcountry_group == 0)

lag3_ols_SSRhigh <- lm(Reserve.Ratio ~ Political_risk + 
                        Inland.water + Area.Harvested + Population +
                        Yield + PPI + num.disaster + 
                        num.drought + num.flood,
                      data = lag3_df_RV.SSRhigh)
lag3_ols_SSRlow <- lm(Reserve.Ratio ~ Political_risk + 
                       Inland.water + Area.Harvested + Population +
                       Yield + PPI + num.disaster + 
                       num.drought + num.flood,
                     data = lag3_df_RV.SSRlow)

lag3_fixed.year_SSRhigh <- plm(Reserve.Ratio ~ Political_risk + 
                                Inland.water + Area.Harvested + Population +
                                Yield + PPI + num.disaster + 
                                num.drought + num.flood,
                              data = lag3_df_RV.SSRhigh, index= c("Country","Year"),
                              effect = "time", model="within")

lag3_fixed.year_SSRlow <- plm(Reserve.Ratio ~ Political_risk + 
                               Inland.water + Area.Harvested + Population +
                               Yield + PPI + num.disaster + 
                               num.drought + num.flood,
                             data = lag3_df_RV.SSRlow, index= c("Country","Year"),
                             effect = "time", model="within")


stargazer(lag3_ols_SSRhigh, lag3_ols_SSRlow,
          lag3_fixed.year_SSRhigh, lag3_fixed.year_SSRlow,
          type = "html", title = "SSR group for reserve ratio",
          omit.stat = c("adj.rsq" ,"f"),
          out = "D:/food security/2021_revise/robust_lag3/SSR.htm")

# ========================
# 5.2.3 indep: external/internal
lag3_ols_RV_inter <- lm(Reserve.Ratio ~ Internal_conflict,
                       data = lag3_df_RV)

lag3_ols_pol_RV_inter <- lm(Reserve.Ratio ~ Internal_conflict +
                             Inland.water + Area.Harvested + Population +
                             Yield + PPI + num.disaster + 
                             num.drought + num.flood,
                           data = lag3_df_RV)

lag3_fixed.year_RV_inter <- plm(Reserve.Ratio ~ Internal_conflict,
                               data = lag3_df_RV, index= c("Country","Year"),
                               effect = "time", model="within")

lag3_fixed.year_pol_RV_inter <- plm(Reserve.Ratio ~ Internal_conflict + 
                                     Inland.water + Area.Harvested + Population +
                                     Yield + PPI + num.disaster + 
                                     num.drought + num.flood,
                                   data = lag3_df_RV, index= c("Country","Year"),
                                   effect = "time", model="within")


lag3_ols_RV_exter <- lm(Reserve.Ratio ~ External_conflict,
                       data = lag3_df_RV)

lag3_ols_pol_RV_exter <- lm(Reserve.Ratio ~ External_conflict + 
                             Inland.water + Area.Harvested + Population +
                             Yield + PPI + num.disaster + 
                             num.drought + num.flood,
                           data = lag3_df_RV)

lag3_fixed.year_RV_exter <- plm(Reserve.Ratio ~ External_conflict,
                               data = lag3_df_RV, index= c("Country","Year"),
                               effect = "time", model="within")

lag3_fixed.year_pol_RV_exter <- plm(Reserve.Ratio ~ External_conflict +
                                     Inland.water + Area.Harvested + Population +
                                     Yield + PPI + num.disaster + 
                                     num.drought + num.flood,
                                   data = lag3_df_RV, index= c("Country","Year"),
                                   effect = "time", model="within")



lag3_ols_RV_exter_inter <- lm(Reserve.Ratio ~  External_conflict + Internal_conflict,
                             data = lag3_df_RV)

lag3_ols_pol_RV_exter_inter <- lm(Reserve.Ratio ~ External_conflict + Internal_conflict +
                                   Inland.water + Area.Harvested + Population +
                                   Yield + PPI + num.disaster + 
                                   num.drought + num.flood,
                                 data = lag3_df_RV)

lag3_fixed.year_RV_exter_inter <- plm(Reserve.Ratio ~ External_conflict + Internal_conflict,
                                     data = lag3_df_RV, index= c("Country","Year"),
                                     effect = "time", model="within")

lag3_fixed.year_pol_RV_exter_inter <- plm(Reserve.Ratio ~ External_conflict + Internal_conflict  +
                                           Inland.water + Area.Harvested + Population +
                                           Yield + PPI + num.disaster + 
                                           num.drought + num.flood,
                                         data = lag3_df_RV, index= c("Country","Year"),
                                         effect = "time", model="within")


stargazer(lag3_ols_RV_exter, lag3_ols_RV_inter, lag3_ols_RV_exter_inter,
          lag3_ols_pol_RV_exter, lag3_ols_pol_RV_inter, lag3_ols_pol_RV_exter_inter,
          lag3_fixed.year_RV_exter, lag3_fixed.year_RV_inter, lag3_fixed.year_RV_exter_inter,
          lag3_fixed.year_pol_RV_exter, lag3_fixed.year_pol_RV_inter, lag3_fixed.year_pol_RV_exter_inter,
          type = "html", title = "Reserve ratio = exter/inter + control",
          omit.stat = c("adj.rsq" ,"f"),
          out = "D:/food security/2021_revise/robust_lag3/RV_inexter.htm")


# ========================
# 5.2.4 indep: RSD
lag3_ols_RV_RSD <- lm(Reserve.Ratio ~ RSD,
                     data = lag3_df_RV)

lag3_ols_pol_RV_RSD <- lm(Reserve.Ratio ~ RSD + Inland.water + 
                           Area.Harvested + Population +
                           Yield + PPI + num.disaster + 
                           num.drought + num.flood,
                         data = lag3_df_RV)
lag3_fixed.year_RV_RSD <- plm(Reserve.Ratio ~ RSD,
                             data = lag3_df_RV, index= c("Country","Year"),
                             effect = "time", model="within")

lag3_fixed.year_pol_RV_RSD <- plm(Reserve.Ratio ~ RSD + Inland.water + 
                                   Area.Harvested + Population +
                                   Yield + PPI + num.disaster + 
                                   num.drought + num.flood,
                                 data = lag3_df_RV, index= c("Country","Year"),
                                 effect = "time", model="within")
stargazer(lag3_ols_RV_RSD, lag3_ols_pol_RV_RSD,
          lag3_fixed.year_RV_RSD, lag3_fixed.year_pol_RV_RSD,
          type = "html", title = "RV = RSD + control",
          omit.stat = c("adj.rsq" ,"f"),
          out = "D:/food security/2021_revise/robust_lag3/RV_RSD.htm")



# =========================
# 5.2.5 Production = indep + control
lag3_df_Pro = subset(ALL, select = c("Country", "Year", "Production",
                        "Internal_conflict", "External_conflict",
                        "Inland.water", "Area.Harvested", "Population", "Yield",
                        "PPI", "num.disaster", "num.drought", "num.flood"))

# lag 3 years
library(data.table)
varname <- colnames(lag3_df_Pro)[!colnames(lag3_df_Pro) %in% c("Country", "Year", "Production")]
lag3_df_Pro <- setDT(lag3_df_Pro)[,paste0(varname):=lapply(.SD, function(x) shift(x,n=3)), by = Country, .SDcols = varname]
detach("package:data.table", TRUE)


lag3_ols_production_inter <- lm(Production ~ Internal_conflict,
                               data = lag3_df_Pro)
lag3_ols_pol_production_inter <- lm(Production ~ Internal_conflict + Inland.water + 
                                     Area.Harvested + Population +
                                     Yield + PPI + num.disaster + 
                                     num.drought + num.flood,
                                   data = lag3_df_Pro)
lag3_fixed.year_production_inter <- plm(Production ~ Internal_conflict,
                                       data = lag3_df_Pro, index= c("Country","Year"),
                                       effect = "time", model="within")

lag3_fixed.year_pol_production_inter <- plm(Production ~ Internal_conflict + Inland.water + 
                                             Area.Harvested + Population +
                                             Yield + PPI + num.disaster + 
                                             num.drought + num.flood,
                                           data = lag3_df_Pro, index= c("Country","Year"),
                                           effect = "time", model="within")


lag3_ols_production_exter <- lm(Production ~ External_conflict,
                               data = lag3_df_Pro)

lag3_ols_pol_production_exter <- lm(Production ~ External_conflict + Inland.water + 
                                     Area.Harvested + Population +
                                     Yield + PPI + num.disaster + 
                                     num.drought + num.flood,
                                   data = lag3_df_Pro)

lag3_fixed.year_production_exter <- plm(Production ~ External_conflict,
                                       data = lag3_df_Pro, index= c("Country","Year"),
                                       effect = "time", model="within")

lag3_fixed.year_pol_production_exter <- plm(Production ~ External_conflict + Inland.water + 
                                             Area.Harvested + Population +
                                             Yield + PPI + num.disaster + 
                                             num.drought + num.flood,
                                           data = lag3_df_Pro, index= c("Country","Year"),
                                           effect = "time", model="within")



# =========================
# 5.2.6 Imports = indep + control
lag3_df_Imp = subset(ALL, select = c("Country", "Year", "Imports",
                        "Internal_conflict", "External_conflict",
                        "Inland.water", "Area.Harvested", "Population", "Yield",
                        "PPI", "num.disaster", "num.drought", "num.flood"))

# lag 3 years
library(data.table)
varname <- colnames(lag3_df_Imp)[!colnames(lag3_df_Imp) %in% c("Country", "Year", "Imports")]
lag3_df_Imp <- setDT(lag3_df_Imp)[,paste0(varname):=lapply(.SD, function(x) shift(x,n=3)), by = Country, .SDcols = varname]
detach("package:data.table", TRUE)


lag3_ols_import_inter <- lm(Imports ~ Internal_conflict,
                           data = lag3_df_Imp)
lag3_ols_pol_import_inter <- lm(Imports ~ Internal_conflict + Inland.water + 
                                 Area.Harvested + Population +
                                 Yield + PPI + num.disaster + 
                                 num.drought + num.flood,
                               data = lag3_df_Imp)
lag3_fixed.year_import_inter <- plm(Imports ~ Internal_conflict,
                                   data = lag3_df_Imp, index= c("Country","Year"),
                                   effect = "time", model="within")

lag3_fixed.year_pol_import_inter <- plm(Imports ~ Internal_conflict + Inland.water + 
                                         Area.Harvested + Population +
                                         Yield + PPI + num.disaster + 
                                         num.drought + num.flood,
                                       data = lag3_df_Imp, index= c("Country","Year"),
                                       effect = "time", model="within")

lag3_ols_import_exter <- lm(Imports ~ External_conflict,
                           data = lag3_df_Imp)
lag3_ols_pol_import_exter <- lm(Imports ~ External_conflict + Inland.water + 
                                 Area.Harvested + Population +
                                 Yield + PPI + num.disaster + 
                                 num.drought + num.flood,
                               data = lag3_df_Imp)
lag3_fixed.year_import_exter <- plm(Imports ~ External_conflict,
                                   data = lag3_df_Imp, index= c("Country","Year"),
                                   effect = "time", model="within")
lag3_fixed.year_pol_import_exter <- plm(Imports ~ External_conflict + Inland.water + 
                                         Area.Harvested + Population +
                                         Yield + PPI + num.disaster + 
                                         num.drought + num.flood,
                                       data = lag3_df_Imp, index= c("Country","Year"),
                                       effect = "time", model="within")


# =========================
# 5.2.7 Exports = indep + control
lag3_df_Exp = subset(ALL, select = c("Country", "Year", "Exports",
                        "Internal_conflict", "External_conflict",
                        "Inland.water", "Area.Harvested", "Population", "Yield",
                        "PPI", "num.disaster", "num.drought", "num.flood"))

# lag 3 years
library(data.table)
varname <- colnames(lag3_df_Exp)[!colnames(lag3_df_Exp) %in% c("Country", "Year", "Exports")]
lag3_df_Exp <- setDT(lag3_df_Exp)[,paste0(varname):=lapply(.SD, function(x) shift(x,n=3)), by = Country, .SDcols = varname]
detach("package:data.table", TRUE)


lag3_ols_export_inter <- lm(Exports ~ Internal_conflict,
                           data = lag3_df_Exp)
lag3_ols_pol_export_inter <- lm(Exports ~ Internal_conflict + Inland.water + 
                                 Area.Harvested + Population +
                                 Yield + PPI + num.disaster + 
                                 num.drought + num.flood,
                               data = lag3_df_Exp)
lag3_fixed.year_export_inter <- plm(Exports ~ Internal_conflict,
                                   data = lag3_df_Exp, index= c("Country","Year"),
                                   effect = "time", model="within")
lag3_fixed.year_pol_export_inter <- plm(Exports ~ Internal_conflict + Inland.water + 
                                         Area.Harvested + Population +
                                         Yield + PPI + num.disaster + 
                                         num.drought + num.flood,
                                       data = lag3_df_Exp, index= c("Country","Year"),
                                       effect = "time", model="within")

lag3_ols_export_exter <- lm(Exports ~ External_conflict,
                           data = lag3_df_Exp)
lag3_ols_pol_export_exter <- lm(Exports ~ External_conflict + Inland.water + 
                                 Area.Harvested + Population +
                                 Yield + PPI + num.disaster + 
                                 num.drought + num.flood,
                               data = lag3_df_Exp)
lag3_fixed.year_export_exter <- plm(Exports ~ External_conflict,
                                   data = lag3_df_Exp, index= c("Country","Year"),
                                   effect = "time", model="within")
lag3_fixed.year_pol_export_exter <- plm(Exports ~ External_conflict + Inland.water + 
                                         Area.Harvested + Population +
                                         Yield + PPI + num.disaster + 
                                         num.drought + num.flood,
                                       data = lag3_df_Exp, index= c("Country","Year"),
                                       effect = "time", model="within")


# ========================= 
# 5.2.8 Consumption = indep + control
lag3_df_Con = subset(ALL, select = c("Country", "Year", "Total.Consumption",
                        "Internal_conflict", "External_conflict",
                        "Inland.water", "Area.Harvested", "Population", "Yield",
                        "PPI", "num.disaster", "num.drought", "num.flood"))

# lag 3 years
library(data.table)
varname <- colnames(lag3_df_Con)[!colnames(lag3_df_Con) %in% c("Country", "Year", "Total.Consumption")]
lag3_df_Con <- setDT(lag3_df_Con)[,paste0(varname):=lapply(.SD, function(x) shift(x,n=3)), by = Country, .SDcols = varname]
detach("package:data.table", TRUE)


lag3_ols_consumption_inter <- lm(Total.Consumption ~ Internal_conflict,
                                data = lag3_df_Con)
lag3_ols_pol_consumption_inter <- lm(Total.Consumption ~ Internal_conflict + Inland.water + 
                                      Area.Harvested + Population +
                                      Yield + PPI + num.disaster + 
                                      num.drought + num.flood,
                                    data = lag3_df_Con)
lag3_fixed.year_consumption_inter <- plm(Total.Consumption ~ Internal_conflict,
                                        data = lag3_df_Con, index= c("Country","Year"),
                                        effect = "time", model="within")
lag3_fixed.year_pol_consumption_inter <- plm(Total.Consumption ~ Internal_conflict + Inland.water + 
                                              Area.Harvested + Population +
                                              Yield + PPI + num.disaster + 
                                              num.drought + num.flood,
                                            data = lag3_df_Con, index= c("Country","Year"),
                                            effect = "time", model="within")


lag3_ols_consumption_exter <- lm(Total.Consumption ~ External_conflict,
                                data = lag3_df_Con)
lag3_ols_pol_consumption_exter <- lm(Total.Consumption ~ External_conflict + Inland.water + 
                                      Area.Harvested + Population +
                                      Yield + PPI + num.disaster + 
                                      num.drought + num.flood,
                                    data = lag3_df_Con)
lag3_fixed.year_consumption_exter <- plm(Total.Consumption ~ External_conflict,
                                        data = lag3_df_Con, index= c("Country","Year"),
                                        effect = "time", model="within")
lag3_fixed.year_pol_consumption_exter <- plm(Total.Consumption ~ External_conflict + Inland.water + 
                                              Area.Harvested + Population +
                                              Yield + PPI + num.disaster + 
                                              num.drought + num.flood,
                                            data = lag3_df_Con, index= c("Country","Year"),
                                            effect = "time", model="within")

stargazer(lag3_ols_production_exter, lag3_ols_pol_production_exter,
          lag3_ols_import_exter, lag3_ols_pol_import_exter,
          lag3_ols_export_exter, lag3_ols_pol_export_exter,
          lag3_ols_consumption_exter, lag3_ols_pol_consumption_exter,
          lag3_fixed.year_production_exter, lag3_fixed.year_pol_production_exter,
          lag3_fixed.year_import_exter, lag3_fixed.year_pol_import_exter,
          lag3_fixed.year_export_exter, lag3_fixed.year_pol_export_exter,
          lag3_fixed.year_consumption_exter, lag3_fixed.year_pol_consumption_exter,
          type = "html", title = "Production/imports/exports/consumption = exter + control",
          omit.stat = c("adj.rsq" ,"f"),
          out = "D:/food security/2021_revise/robust_lag3/other_exter.htm")


stargazer(lag3_ols_production_inter, lag3_ols_pol_production_inter,
          lag3_ols_import_inter, lag3_ols_pol_import_inter,
          lag3_ols_export_inter, lag3_ols_pol_export_inter,
          lag3_ols_consumption_inter, lag3_ols_pol_consumption_inter,
          lag3_fixed.year_production_inter, lag3_fixed.year_pol_production_inter,
          lag3_fixed.year_import_inter, lag3_fixed.year_pol_import_inter,
          lag3_fixed.year_export_inter, lag3_fixed.year_pol_export_inter,
          lag3_fixed.year_consumption_inter, lag3_fixed.year_pol_consumption_inter,
          type = "html", title = "Production/imports/exports/consumption = inter + control",
          omit.stat = c("adj.rsq" ,"f"),
          out = "D:/food security/2021_revise/robust_lag3/other_inter.htm")


# ========================= # ========================= 
# 5.4 Heckman two-stage procedure
library(sampleSelection)
# ========================
# 5.4.1 use all data
# step 1. Probit model
df_heckman_pol = subset(ALL, select = c("Country", "Year", "Political_risk", "Reserve.Ratio",
                                     "Inland.water", "Area.Harvested", "Population", "Yield",
                                     "PPI", "num.disaster", "num.drought", "num.flood"))
df_heckman_pol$political_dummy <- ifelse(df_heckman_pol$Political_risk > mean(df_heckman_pol$Political_risk, na.rm = TRUE), 1, 0)
df_heckman_pol$RV_dummy <- ifelse(df_heckman_pol$Reserve.Ratio > mean(df_heckman_pol$Reserve.Ratio, na.rm = TRUE), 1, 0)
probit_fixed.year_alldata <- glm(political_dummy ~ Inland.water + Area.Harvested + Population + Yield
                                 + PPI + num.disaster + num.drought + num.flood + factor(Year), 
                                 data = df_heckman_pol, family = binomial(link = "probit"))
df_heckman_pol$IMR <- invMillsRatio(probit_fixed.year_alldata)$IMR1
# summary(probit_fixed.year_alldata)

# step 2. logit model
# lag a year for x
library(data.table)
varname <- colnames(df_heckman_pol)[!colnames(df_heckman_pol) %in% c("Country", "Year", "Reserve.Ratio", "RV_dummy")]
df_heckman_pol <- setDT(df_heckman_pol)[,paste0(varname):=lapply(.SD, shift), by = Country, .SDcols = varname]
detach("package:data.table", TRUE)
logit_fixed.year_alldata <- glm(RV_dummy ~ Political_risk + IMR + Inland.water + Area.Harvested + Population + Yield + PPI + num.disaster + 
                                num.drought + num.flood + factor(Year),
                                data = df_heckman_pol, family = binomial(link = "logit"))
# summary(logit_fixed.year_alldata)
stargazer(probit_fixed.year_alldata, logit_fixed.year_alldata,
          column.labels = c("stage 1", "stage 2"),
          column.separate = c(1,1),
          ord.intercepts = TRUE,
          type = "html", title = "alldata",
          omit = "Year",
          omit.stat = c("adj.rsq" ,"f"),
          out = "D:/food security/2021_revise/robust_heckman/alldata.htm")


# ========================
# 5.4.2 external
# step 1. Probit model
df_heckman_ext = subset(ALL, select = c("Country", "Year", "External_conflict", "Reserve.Ratio",
                                        "Inland.water", "Area.Harvested", "Population", "Yield",
                                        "PPI", "num.disaster", "num.drought", "num.flood"))
df_heckman_ext$external_dummy <- ifelse(df_heckman_ext$External_conflict > mean(df_heckman_ext$External_conflict, na.rm = TRUE), 1, 0)
df_heckman_ext$RV_dummy <- ifelse(df_heckman_ext$Reserve.Ratio > mean(df_heckman_ext$Reserve.Ratio, na.rm = TRUE), 1, 0)
probit_fixed.year_ext <- glm(external_dummy ~ Inland.water + Area.Harvested + Population + Yield
                                 + PPI + num.disaster + num.drought + num.flood + factor(Year), 
                                 data = df_heckman_ext, family = binomial(link = "probit"))
df_heckman_ext$IMR <- invMillsRatio(probit_fixed.year_ext)$IMR1
# summary(probit_fixed.year_ext)

# step 2. logit model
# lag a year for x
library(data.table)
varname <- colnames(df_heckman_ext)[!colnames(df_heckman_ext) %in% c("Country", "Year", "Reserve.Ratio", "RV_dummy")]
df_heckman_ext <- setDT(df_heckman_ext)[,paste0(varname):=lapply(.SD, shift), by = Country, .SDcols = varname]
detach("package:data.table", TRUE)
logit_fixed.year_ext <- glm(RV_dummy ~ External_conflict + IMR + Inland.water + Area.Harvested + Population + Yield + PPI + num.disaster + 
                                  num.drought + num.flood + factor(Year),
                                data = df_heckman_ext, family = binomial(link = "logit"))
# summary(logit_fixed.year_ext)
stargazer(probit_fixed.year_ext, logit_fixed.year_ext,
          column.labels = c("stage 1", "stage 2"),
          column.separate = c(1,1),
          ord.intercepts = TRUE,
          type = "html", title = "external risk",
          omit = "Year",
          omit.stat = c("adj.rsq" ,"f"),
          out = "D:/food security/2021_revise/robust_heckman/external.htm")


# ========================
# 5.4.3 internal
# step 1. Probit model
df_heckman_int = subset(ALL, select = c("Country", "Year", "Internal_conflict", "Reserve.Ratio",
                                        "Inland.water", "Area.Harvested", "Population", "Yield",
                                        "PPI", "num.disaster", "num.drought", "num.flood"))
df_heckman_int$Internal_dummy <- ifelse(df_heckman_int$Internal_conflict > mean(df_heckman_int$Internal_conflict, na.rm = TRUE), 1, 0)
df_heckman_int$RV_dummy <- ifelse(df_heckman_int$Reserve.Ratio > mean(df_heckman_int$Reserve.Ratio, na.rm = TRUE), 1, 0)
probit_fixed.year_int <- glm(Internal_dummy ~ Inland.water + Area.Harvested + Population + Yield
                             + PPI + num.disaster + num.drought + num.flood + factor(Year), 
                             data = df_heckman_int, family = binomial(link = "probit"))
df_heckman_int$IMR <- invMillsRatio(probit_fixed.year_int)$IMR1
# summary(probit_fixed.year_int)

# step 2. logit model
# lag a year for x
library(data.table)
varname <- colnames(df_heckman_int)[!colnames(df_heckman_int) %in% c("Country", "Year", "Reserve.Ratio", "RV_dummy")]
df_heckman_int <- setDT(df_heckman_int)[,paste0(varname):=lapply(.SD, shift), by = Country, .SDcols = varname]
detach("package:data.table", TRUE)
logit_fixed.year_int <- glm(RV_dummy ~ Internal_conflict + IMR + Inland.water + Area.Harvested + Population + Yield + PPI + num.disaster + 
                              num.drought + num.flood + factor(Year),
                            data = df_heckman_int, family = binomial(link = "logit"))
# summary(logit_fixed.year_int)
stargazer(probit_fixed.year_int, logit_fixed.year_int,
          column.labels = c("stage 1", "stage 2"),
          column.separate = c(1,1),
          ord.intercepts = TRUE,
          type = "html", title = "internal risk",
          omit = "Year",
          omit.stat = c("adj.rsq" ,"f"),
          out = "D:/food security/2021_revise/robust_heckman/internal.htm")

